@@ -611,17 +611,22 @@ class Sf:
         return compound_field_names
     
     
-    async def get_picklist_values_by_object_record_type(sf, object: str):
-        object_record_type_ids = sf.query(f"Select Id, Name From RecordType Where SobjectType = '{object}'").apply(lambda row: {"Id": row['Id'], "Name": row['Name']}, axis=1).to_list()
-        object_describe = sf.sf_api_call(f"/services/data/{sf.api_version}/ui-api/object-info/{object}")['fields']
+    async def get_picklist_values_by_object_record_type(self, object: str):
+        object_record_type_ids = self.query(f"Select Id, Name From RecordType Where SobjectType = '{object}'").apply(lambda row: {"Id": row['Id'], "Name": row['Name']}, axis=1)
+        if len(object_record_type_ids) == 0:
+            object_record_type_ids = pd.Series([{"Id": "012000000000000AAA", "Name": "Master"}]).to_list()
+        else:
+            object_record_type_ids = object_record_type_ids.to_list()
+            
+        object_describe = self.sf_api_call(f"/services/data/{self.api_version}/ui-api/object-info/{object}")['fields']
         controlling_fields = []
         for field, values in object_describe.items():
             controlling_fields.append({"Field": field, "Controlling Field": "" if values['controllingFields'] == [] else "; ".join(values['controllingFields'])})
         controlling_fields = pd.DataFrame(controlling_fields)
 
-        def record_type_picklist_retriever(sf, object, record_type_id, record_type_name):
+        def record_type_picklist_retriever(self, object, record_type_id, record_type_name):
             result = []
-            for key, value in sf.sf_api_call(f"/services/data/{sf.api_version}/ui-api/object-info/{object}/picklist-values/{record_type_id}")['picklistFieldValues'].items():
+            for key, value in self.sf_api_call(f"/services/data/{self.api_version}/ui-api/object-info/{object}/picklist-values/{record_type_id}")['picklistFieldValues'].items():
                 result.append({"Field_API": key, "controllerValues": value['controllerValues'], "defaultValue":  value['defaultValue'], "values": value['values']})
             final_result_pd = json_normalize(result, ['values'], ['defaultValue', 'controllerValues', 'Field_API'])
             ## Converts the validFor numerical codes i.e. [0,2] to it's corresponding text values by looking it up on the controllerValues column i.e. {'Web': 0, 'Phone Inquiry': 1, 'Partner Reference': 2 ... }
@@ -636,7 +641,7 @@ class Sf:
             return final_result_pd
 
         async_picklist_rt_retrieve = async_wrap(record_type_picklist_retriever)
-        results = pd.concat(await asyncio.gather(*[async_picklist_rt_retrieve(sf, object, record_type_id['Id'], record_type_id['Name']) for record_type_id in object_record_type_ids]))
+        results = pd.concat(await asyncio.gather(*[async_picklist_rt_retrieve(self, object, record_type_id['Id'], record_type_id['Name']) for record_type_id in object_record_type_ids]))
         results = results[['Object', 'RecordTypeName', 'Field_API', 'Controlling Field', 'defaultValueLabel', 'defaultValueValue', 'label', 'value', 'validFor']]
         return results
 
