@@ -1,5 +1,5 @@
 from collections import OrderedDict
-from pandas import pd
+import pandas as pd
 
 
 def recursive_walk(od_field: OrderedDict):
